@@ -47,8 +47,11 @@ class CacheMiddleware(object):
     def cached(self, resource):
         """Return True if the specified resource is cached; the resource is
         the cache identifier."""
+        cache_name = self.resource_cache_name(resource)
 
-        return os.path.exists(self.resource_cache_name(resource))
+        return (
+            os.path.exists(cache_name)
+            and not os.path.isdir(cache_name))
 
     def store(self, resource, contents):
         """Store the resource contents in the cache."""
@@ -90,7 +93,8 @@ class CacheMiddleware(object):
             response['contents'] = self.load(identifier)
         else:
             response['contents'] = self.app(environ, sr)
-            self.store(identifier, response['contents'])
+            if response['status'] == '200 OK':
+                self.store(identifier, response['contents'])
 
         start_response(response['status'], response['headers'])
         return response['contents']
